@@ -28,7 +28,6 @@
 #include <qlat-utils/complex.h>
 #include <qlat-utils/array.h>
 #include <qlat-utils/vector.h>
-#include <qlat-utils/coordinate.h>
 
 #include <unistd.h>
 
@@ -43,4 +42,11 @@ qacc T sqr(const T& x)
   return x * x;
 }
 
+inline void warn(const std::string& str = "")
+{
+  if (str != "") {
+    displayln_info(ssprintf("WARNING: %s", str.c_str()));
+  }
+}
+
 }  // namespace qlat
